diff --git a/books/bookvol4.pamphlet b/books/bookvol4.pamphlet
index 8345070..8f1aaa7 100644
--- a/books/bookvol4.pamphlet
+++ b/books/bookvol4.pamphlet
@@ -4678,6 +4678,59 @@ digraph pic {
 }
 \end{verbatim}
 
+In book Volume 10.3 there are .ps files generated for each domain.
+
+These pictures show the category, domain, or package that is the highest
+in the algebra tower. That means that the parent domain has to be compiled
+before this domain. Since the parent is the highest in the tower then all
+of the other domains will already have been compiled.
+
+We derive the dependency information from the algebra Makefile.
+In order to insert algebra into the tower we derive its parents
+and then create a table of all of the parents. However, the table is
+mostly comments except for the highest parent. So if the highest parent
+is compiled in layer 12 then the new domain is inserted into layer 13.
+
+The graph information at the end of a domain (e.g. UTSZ) contains only
+the uncommented information. It is used to generate the picture. So
+for UTSZ we see:
+
+\begin{verbatim}
+"UTSZ" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTSZ"]
+"ACFS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ACFS"]
+"UTSZ" -> "ACFS"
+\end{verbatim}
+
+This tells us several pieces of information. UTSZ depends on ACFS
+as the highest parent. ACFS is in layer 17 so is in layer 18.
+ACFS is a category (color 4488FF) and lives in bookvol10.2.
+UTSZ is a domain (color 88FF44, note the rotation of hex codes, 
+a package is color FF4488) and lives in bookvol10.3.
+
+The necessary stanzas exist after each algebra domain.
+Copy the stanza into a digraph block and run the dot function.
+So for the UTSZ domain we would create a file (e.g. called 'pic')
+that contains a block that reads:
+\begin{verbatim}
+digraph pic {
+ fontsize=10;
+ bgcolor="#FFFF66";
+ node [shape=box, color=white, style=filled];
+
+"UTSZ" [color="#88FF44",href="bookvol10.3.pdf#nameddest=UTSZ"]
+"ACFS" [color="#4488FF",href="bookvol10.2.pdf#nameddest=ACFS"]
+"UTSZ" -> "ACFS"
+
+}
+\end{verbatim}
+and then run the command:
+\begin{verbatim}
+  dot -Tps <pic >pic.ps
+  cp pic.ps ps/v103univariatetaylorseriesczero.ps
+\end{verbatim}
+The output file ``ps/v103univariatetaylorseriesczero.ps'' is included
+after the pagepic of each domain in the book.
+
 \section{Adding or Editing pages in Hyperdoc}
 In Axiom it is easy to develop new pages in hyperdoc.
 All of the hyperdoc pages live in bookvol7.1.pamphlet.
diff --git a/changelog b/changelog
index b7da7c9..e184168 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,5 @@
+20100419 tpd src/axiom-website/patches.html 20100419.05.tpd.patch
+20100419 tpd books/bookvol4 document how to make graphs in algebra books
 20100419 tpd src/axiom-website/patches.html 20100419.04.tpd.patch
 20100419 tpd books/ps/v104finitefieldsquarefreedecomposition.ps doc FFSQFR
 20100419 tpd books/ps/v103univariatetaylorseriesczero.ps document UTSZ
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 7e5cb4b..d197cd1 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -2645,5 +2645,7 @@ books/bookvolbib,bookvol1 rename and align biblio sections<br/>
 books/bookvol10.4 add FiniteFieldSquareFreeDecomposition<br/>
 <a href="patches/20100419.04.tpd.patch">20100419.04.tpd.patch</a>
 books/bookvol10.3 improve UnivariateTaylorSeriesCZero docs<br/>
+<a href="patches/20100419.05.tpd.patch">20100419.05.tpd.patch</a>
+books/bookvol4 document how to make graphs in algebra books<br/>
  </body>
 </html>
